require_relative '../base_spec'

describe Abrupt::Transformation::Website::Complexity do
  it_should_behave_like 'convertable object' do
    let(:expected_values) do
      [{ contrast: { _1: { A_tag_With_Low_Contrast: 0,
                           TextNodes_With_Low_Contrast: 0,
                           paragrahps_with_too_long_lines: 0 } },
         vizweb: { numberOfLeaves: 1,
                   textArea: '0',
                   numberOfTextGroups: 0,
                   visualComplexity: 0.79690559961371,
                   numberOfImageAreas: 0,
                   hue: 0.78842163085938,
                   horizontalSymmetry: '1',
                   horizontalBalance: 'null',
                   colorfulness: 13.723379102371,
                   nontextArea: 1.3333333333333 },
         differenceMatrix: [{ matrix: [0.0,
                                       37.735924528226,
                                       69.0,
                                       18.0,
                                       41.569219381653,
                                       24.657656011876,
                                       12.649110640674,
                                       37.735924528226,
                                       0.0,
                                       34.885527085025,
                                       21.260291625469,
                                       25.612496949731,
                                       26.832815729997,
                                       33.226495451672,
                                       69.0,
                                       34.885527085025,
                                       0.0,
                                       51.0,
                                       56.364882684168,
                                       60.934390946328,
                                       66.098411478643,
                                       18.0,
                                       21.260291625469,
                                       51.0,
                                       0.0,
                                       34.467375879228,
                                       22.360679774998,
                                       18.439088914586,
                                       41.569219381653,
                                       25.612496949731,
                                       56.364882684168,
                                       34.467375879228,
                                       0.0,
                                       20.396078054371,
                                       33.466401061363,
                                       24.657656011876,
                                       26.832815729997,
                                       60.934390946328,
                                       22.360679774998,
                                       20.396078054371,
                                       0.0,
                                       21.908902300207,
                                       12.649110640674,
                                       33.226495451672,
                                       66.098411478643,
                                       18.439088914586,
                                       33.466401061363,
                                       21.908902300207,
                                       0.0],
                              palette: [4.0,
                                        4.0,
                                        4.0,
                                        12.0,
                                        12.0,
                                        40.0,
                                        4.0,
                                        4.0,
                                        73.0,
                                        4.0,
                                        4.0,
                                        22.0,
                                        28.0,
                                        28.0,
                                        28.0,
                                        12.0,
                                        24.0,
                                        16.0,
                                        16.0,
                                        4.0,
                                        8.0] }],
         vicram: { complexity: 0.6395 },
         ratios: { pageSize: { pageSize_in_pixel_squared: 289_600,
                               pageWidth_in_pixel: 400,
                               pageHeight_in_pixel: 724 },
                   img_Tag: { img_Area_in_pixel_squared: 2730,
                              img_document_tag_percentage: 0.94267955801105,
                              img_document_tag_ratio: 106.08058608059 } } },
       { contrast: { _1: { A_tag_With_Low_Contrast: 1,
                           TextNodes_With_Low_Contrast: 1,
                           paragrahps_with_too_long_lines: 0 } },
         vizweb: { numberOfLeaves: 17,
                   textArea: '0.0074666341145833',
                   numberOfTextGroups: 1,
                   visualComplexity: 0.98656564934711,
                   numberOfImageAreas: 1,
                   hue: 0.92692057291667,
                   horizontalSymmetry: '1',
                   horizontalBalance: 'null',
                   colorfulness: 13.811903651406,
                   nontextArea: 0.0044080946180556 },
         differenceMatrix: [{ matrix: [0.0,
                                       347.57157536254,
                                       83.138438763306,
                                       155.335121592,
                                       193.98969044771,
                                       207.84609690827,
                                       67.0,
                                       347.57157536254,
                                       0.0,
                                       264.43524727237,
                                       192.26284092356,
                                       153.5903642811,
                                       139.73546436034,
                                       314.05254337451,
                                       83.138438763306,
                                       264.43524727237,
                                       0.0,
                                       72.228803118977,
                                       110.85125168441,
                                       124.70765814496,
                                       70.491134194308,
                                       155.335121592,
                                       192.26284092356,
                                       72.228803118977,
                                       0.0,
                                       38.794329482542,
                                       52.621288467691,
                                       129.71507237018,
                                       193.98969044771,
                                       153.5903642811,
                                       110.85125168441,
                                       38.794329482542,
                                       0.0,
                                       13.856406460551,
                                       164.66025628548,
                                       207.84609690827,
                                       139.73546436034,
                                       124.70765814496,
                                       52.621288467691,
                                       13.856406460551,
                                       0.0,
                                       177.78920102188,
                                       67.0,
                                       314.05254337451,
                                       70.491134194308,
                                       129.71507237018,
                                       164.66025628548,
                                       177.78920102188,
                                       0.0],
                              palette: [4.0,
                                        4.0,
                                        4.0,
                                        206.0,
                                        205.0,
                                        203.0,
                                        52.0,
                                        52.0,
                                        52.0,
                                        96.0,
                                        93.0,
                                        92.0,
                                        116.0,
                                        116.0,
                                        116.0,
                                        124.0,
                                        124.0,
                                        124.0,
                                        4.0,
                                        4.0,
                                        71.0] }],
         vicram: { complexity: 1.3497 },
         ratios: { pageSize: { pageSize_in_pixel_squared: 1_164_339,
                               pageWidth_in_pixel: 619,
                               pageHeight_in_pixel: 1881 },
                   img_Tag: { img_Area_in_pixel_squared: 3612,
                              img_document_tag_percentage: 0.3102189310845,
                              img_document_tag_ratio: 322.35299003322 } } }]
    end
  end
end
