require_relative '../base_spec'

describe Abrupt::Transformation::Website::Input do
  it_should_behave_like 'convertable object' do
    let(:expected_values) do
      [{ text: [{ id: 'termin_von',
                  maxlength: 10,
                  name: 'von',
                  value: nil,
                  class: 'text',
                  required: nil,
                  type: 'text',
                  size: 10 },
                { id: 'termin_bis',
                  maxlength: 10,
                  name: 'bis',
                  value: nil,
                  class: 'text',
                  type: 'text',
                  size: 10 },
                { id: 'termin_zeit',
                  maxlength: 5,
                  name: 'zeit',
                  value: nil,
                  class: 'textdisabled',
                  type: 'text',
                  disabled: nil,
                  size: 5 },
                { id: 'name',
                  maxlength: 60,
                  placeholder: 'Vorname Nachname',
                  name: 'name',
                  value: nil,
                  class: 'text',
                  required: nil,
                  type: 'text',
                  size: 40 },
                { maxlength: 60,
                  placeholder: 'Straße Hausnummer',
                  name: 'strasse',
                  value: nil,
                  class: 'text',
                  type: 'text',
                  size: 40 },
                { maxlength: 60,
                  placeholder: 'PLZ Ort',
                  name: 'ort',
                  value: nil,
                  class: 'text',
                  type: 'text',
                  size: 40 },
                { maxlength: 60,
                  name: 'telefon',
                  value: nil,
                  class: 'text',
                  type: 'text',
                  size: 40 },
                { id: 'lieferungOrt',
                  placeholder: 'Lieferort',
                  name: 'lieferungOrt',
                  value: nil,
                  type: 'text',
                  size: 20 },
                { maxlength: 60,
                  name: 'aufmerksam_sonstiges',
                  value: nil,
                  class: 'text',
                  type: 'text',
                  size: 40 }],
         submit: [{ name: 'action',
                    value: 'Anfrage senden',
                    onclick: 'return(senden());',
                    class: 'bold',
                    type: 'submit' }],
         email: [{ id: 'email',
                   maxlength: 60,
                   name: 'email',
                   value: nil,
                   class: 'text',
                   required: nil,
                   type: 'email',
                   size: 40 }],
         textarea: [{ cols: 60, name: 'bemerkung', rows: 5 }],
         checkbox: [{ id: 'blumenSeide',
                      name: 'blumen',
                      value: 'Seidenrosen',
                      type: 'checkbox' },
                    { id: 'herz', name: 'herz',
                      value: 'Herz',
                      type: 'checkbox' },
                    { id: 'aufmerksam_internet',
                      name: 'aufmerksam_internet',
                      value: 'Internet',
                      type: 'checkbox' },
                    { id: 'aufmerksam_messe',
                      name: 'aufmerksam_messe',
                      value: 'Messe',
                      type: 'checkbox' },
                    { id: 'aufmerksam_zeitschrift',
                      name: 'aufmerksam_zeitschrift',
                      value: 'Zeitschrift',
                      type: 'checkbox' },
                    { id: 'aufmerksam_empfehlung',
                      name: 'aufmerksam_empfehlung',
                      value: 'Empfehlung',
                      type: 'checkbox' },
                    { id: 'agb',
                      name: 'agb',
                      value: 'ja',
                      required: nil,
                      type: 'checkbox' }],
         radio: [{ id: 'angebot_3tage',
                   name: 'angebot',
                   value: '3 Tage',
                   onclick: "angebotGewaehlt('3Tage');",
                   required: nil,
                   type: 'radio' },
                 { id: 'angebot_hz_fahrer',
                   name: 'angebot',
                   value: 'HZ-Fahrer',
                   onclick: "angebotGewaehlt('HZ-Fahrer');",
                   required: nil,
                   type: 'radio' },
                 { id: 'angebot_2tage',
                   name: 'angebot',
                   value: '2 Tage',
                   onclick: "angebotGewaehlt('2Tage');",
                   required: nil,
                   type: 'radio' },
                 { id: 'angebot_rikschafahrt',
                   name: 'angebot',
                   value: 'Rikschafahrt',
                   onclick: "angebotGewaehlt('Rikschafahrt');",
                   required: nil,
                   type: 'radio' },
                 { id: 'angebot_1tag',
                   name: 'angebot',
                   value: '1 Tag',
                   onclick: "angebotGewaehlt('1Tag');",
                   required: nil,
                   type: 'radio' },
                 { id: 'angebot_mondscheinfahrt',
                   name: 'angebot',
                   value: 'Mondscheinfahrt',
                   onclick: "angebotGewaehlt('Mondscheinfahrt');",
                   required: nil,
                   type: 'radio' },
                 { id: 'angebot_sonstiges',
                   name: 'angebot',
                   value: 'sonstiges',
                   onclick: "angebotGewaehlt('sonstiges');",
                   required: nil,
                   type: 'radio' },
                 { id: 'angebot_picknicktour',
                   name: 'angebot',
                   value: 'Picknicktour',
                   onclick: "angebotGewaehlt('Picknicktour');",
                   required: nil,
                   type: 'radio' },
                 { id: 'angebot_sonstigesFahrer',
                   name: 'angebot',
                   value: 'sonstiges Fahrer',
                   onclick: "angebotGewaehlt('sonstigesFahrer');",
                   required: nil,
                   type: 'radio' },
                 { id: 'lieferungBringen',
                   name: 'lieferung',
                   value: 'Bringen',
                   type: 'radio',
                   checked: nil },
                 { id: 'lieferungAbholung',
                   name: 'lieferung',
                   value: 'Abholung',
                   type: 'radio' },
                 { id: 'lieferungAnhaenger',
                   name: 'lieferung',
                   value: 'Anhänger',
                   type: 'radio' }] }]
    end
  end
end
